@@ -50,7 +50,7 @@ def valider_schema_yaml_infos_question(contenu_fichier):
         },
     )
 
-    if "type" in contenu_fichier and contenu_fichier["type"] == "prog":
+    if "type" in contenu_fichier and contenu_fichier["type"].lower() == "prog":
         schemas_à_valider = "question_prog"
     else:
         schemas_à_valider = "question_base"
